@@ -1,11 +1,7 @@
 from mona_sdk import Client
 # For regular smadar's user
-#client_id = "40c08ee6-f411-41b1-9752-80d98897aae6"
-#secret_key = "5694fad0-e372-488e-89cf-22ed8693a5a2"
-
-# smadar_test_del_03092022
-client_id = "737caa6d-07dd-4859-b267-3dc7ca765ddf"
-secret_key = "8813b3f3-c0e6-4286-a0db-99c55d1eaecf"
+client_id = "40c08ee6-f411-41b1-9752-80d98897aae6"
+secret_key = "5694fad0-e372-488e-89cf-22ed8693a5a2"
 
 
 my_mona_client = Client(
