@@ -1,16 +1,20 @@
+import time
 from random import randint
 
 from mona_sdk import Client, MonaSingleMessage
 
+
 # Es monitor test
 client_id = "e8018061-0559-4b22-b041-f10ef5848cd6"
 secret_key = "9df5eefb-de6d-4529-b79a-60b398353449"
 
 CONTEXT_CLASSES = [
-    "SMADAR_TEST_IN_CONFIG_SAMPLED",
-    "SMADAR_TEST_IN_CONFIG_SAMPLED_NOT_TAKEN",
-    "SMADAR_TEST_TAKES_DEFAULT",
-    "SMADAR_TEST_IN_CONFIG_FULLY_TAKEN",
+    "smadar_test1",
+    "smadar_test2",
+    "smadar_test3",
+    "smadar_test4",
+    "smadar_test5",
+    "smadar_test6"
 ]
 NUMBER_OF_MESSAGES_PER_CONTEXT_CLASS = 10000
 
@@ -32,6 +36,7 @@ my_mona_client = Client(
     sampling_config_name="smadar_neti_test"
 )
 
+total_requests_time = 0
 
 for context_class in CONTEXT_CLASSES:
     messages = []
@@ -43,6 +48,14 @@ for context_class in CONTEXT_CLASSES:
                 contextId=str(random_with_N_digits(10)),
             )
         )
+    print(f"sending context_class {context_class}")
+    start_time = time.time()
 
     succeed_to_export = my_mona_client.export_batch(messages)
-    print(f"\n{context_class}: {succeed_to_export}")
+
+    total_requests_time += (time.time() - start_time)
+    print(f"sent context_class {context_class}")
+    #print(f"\n{context_class}: {succeed_to_export}")
+
+
+print("--- %s seconds ---" % total_requests_time)
\ No newline at end of file
